@@ -72,7 +72,7 @@ class DatazillaPerfPoster(object):
                  log_level='INFO'):
         # Set up logging
         handler = mozlog.StreamHandler()
-        handler.setFormatter(B2GPerfFormatter())
+        handler.setFormatter(mozlog.MozFormatter(include_timestamp=True))
         self.logger = mozlog.getLogger(self.__class__.__name__, handler)
         self.logger.setLevel(getattr(mozlog, log_level.upper()))
 
@@ -89,21 +89,19 @@ class DatazillaPerfPoster(object):
 
         if self.device.is_android_build:
             self.logger.debug('Getting gaia, gecko and build revisions')
-            try:
-                app_zip = self.device.manager.pullFile(
-                    '/data/local/webapps/settings.gaiamobile.org/'
-                    'application.zip')
-                zip_file = zipfile.ZipFile(StringIO(app_zip))
-                with zip_file.open('resources/gaia_commit.txt') as f:
-                    gaia_revision = f.read().splitlines()[0]
-                    self.logger.debug('Gaia revision: %s' % gaia_revision)
-                    self.ancillary_data['gaia_revision'] = gaia_revision
-
-            except zipfile.BadZipfile:
+            for path in ['/system/b2g', '/data/local']:
+                path += '/webapps/settings.gaiamobile.org/application.zip'
+                if self.device.manager.fileExists(path):
+                    zip_file = zipfile.ZipFile(StringIO(
+                        self.device.manager.pullFile(path)))
+                    with zip_file.open('resources/gaia_commit.txt') as f:
+                        gaia_revision = f.read().splitlines()[0]
+                        self.logger.debug('Gaia revision: %s' % gaia_revision)
+                        self.ancillary_data['gaia_revision'] = gaia_revision
+                    break
+            else:
                 self.logger.warn('application.zip does not exist, perhaps '
                                  'gaia has not been flashed to the device')
-                pass
-
             try:
                 sources_xml = sources and xml.dom.minidom.parse(sources) or \
                     xml.dom.minidom.parseString(self.device.manager.catFile(
@@ -121,6 +119,19 @@ class DatazillaPerfPoster(object):
                 self.logger.warn('Unable to get revisions from sources')
                 pass
 
+            self.logger.debug('Getting build properties')
+            build_props = self.device.manager.pullFile('/system/build.prop')
+            desired_props = ('ro.build.version.incremental',
+                             'ro.build.version.release',
+                             'ro.build.date.utc')
+            for line in build_props.split('\n'):
+                if not line.strip().startswith('#') and '=' in line:
+                    name, value = [s.strip() for s in line.split('=', 1)]
+                    if name in desired_props:
+                        self.logger.debug('Build property: %s (%s)' % (
+                            name, value))
+                        self.ancillary_data[name] = value
+
         self.required = {
             'gaia revision': self.ancillary_data.get('gaia_revision'),
             'gecko revision': self.ancillary_data.get('gecko_revision'),
@@ -263,19 +274,6 @@ class B2GPerfRunner(DatazillaPerfPoster):
             sys.exit(1)
 
 
-class B2GPerfFormatter(mozlog.MozFormatter):
-
-    def format(self, record):
-        record.message = record.getMessage()
-        import datetime
-        record.timestamp = datetime.datetime.fromtimestamp(
-            int(record.created)).strftime('%Y-%m-%d %H:%M:%S')
-        sep = ' | '
-        fmt = sep.join(['%(timestamp)s', '%(name)s', '%(levelname)s',
-                        '%(message)s'])
-        return fmt % record.__dict__
-
-
 class B2GPerfTest(object):
 
     def __init__(self, marionette, app_name, logger, iterations, delay,
